@@ -59,9 +59,11 @@ class API:
 
         if json_ is not None:  # static JSON string
             self.links = json.loads(json_)['links']
+            self.response = json_
         else:
             response = http_get(url, headers=self.headers, auth=self.auth).json()
             self.links = response['links']
+            self.response = response
 
     def api(self) -> dict:
         """
@@ -151,6 +153,7 @@ class API:
         """
 
         url = self._build_url(path)
+        self.request = url
 
         LOGGER.debug('Request: {}'.format(url))
         LOGGER.debug('Params: {}'.format(kwargs))
@@ -163,6 +166,8 @@ class API:
         if response.status_code != requests.codes.ok:
             raise RuntimeError(response.text)
 
+        self.request = response.url
+
         if as_dict:
             return response.json()
         else:
